@@ -6,7 +6,7 @@
  *                                                                         *
  ***********************IMPORTANT NSOCK LICENSE TERMS***********************
  *                                                                         *
- * The nsock parallel socket event library is (C) 1999-2013 Insecure.Com   *
+ * The nsock parallel socket event library is (C) 1999-2015 Insecure.Com   *
  * LLC This library is free software; you may redistribute and/or          *
  * modify it under the terms of the GNU General Public License as          *
  * published by the Free Software Foundation; Version 2.  This guarantees  *
@@ -30,8 +30,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -56,7 +55,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nsock_iod.c 32741 2014-02-20 18:44:12Z dmiller $ */
+/* $Id: nsock_iod.c 34756 2015-06-27 08:21:53Z henri $ */
 
 #include "nsock.h"
 #include "nsock_internal.h"
@@ -72,11 +71,11 @@
     
 
 /* nsock_iod is like a "file descriptor" for the nsock library. You use it to
- * request events. And here is how you create an nsock_iod. nsi_new returns
+ * request events. And here is how you create an nsock_iod. nsock_iod_new returns
  * NULL if the iod cannot be allocated. Pass NULL as userdata if you don't want
  * to immediately associate any user data with the iod. */
-nsock_iod nsi_new(nsock_pool nsockp, void *userdata) {
-  return nsi_new2(nsockp, -1, userdata);
+nsock_iod nsock_iod_new(nsock_pool nsockp, void *userdata) {
+  return nsock_iod_new2(nsockp, -1, userdata);
 }
 
 /* This version allows you to associate an existing sd with the msi so that you
@@ -85,17 +84,17 @@ nsock_iod nsi_new(nsock_pool nsockp, void *userdata) {
  * various sockets.  STDIN_FILENO is a special case, however. Any other sd is
  * dup()ed, so you may close or otherwise manipulate your copy.  The duped copy
  * will be destroyed when the nsi is destroyed. */
-nsock_iod nsi_new2(nsock_pool nsockp, int sd, void *userdata) {
-  mspool *nsp = (mspool *)nsockp;
+nsock_iod nsock_iod_new2(nsock_pool nsockp, int sd, void *userdata) {
+  struct npool *nsp = (struct npool *)nsockp;
   gh_lnode_t *lnode;
-  msiod *nsi;
+  struct niod *nsi;
 
   lnode = gh_list_pop(&nsp->free_iods);
   if (!lnode) {
-    nsi = (msiod *)safe_malloc(sizeof(msiod));
+    nsi = (struct niod *)safe_malloc(sizeof(*nsi));
     memset(nsi, 0, sizeof(*nsi));
   } else {
-    nsi = container_of(lnode, msiod, nodeq);
+    nsi = container_of(lnode, struct niod, nodeq);
   }
 
   if (sd == -1) {
@@ -125,7 +124,7 @@ nsock_iod nsi_new2(nsock_pool nsockp, int sd, void *userdata) {
   nsi->write_count = 0;
 
   nsi->userdata = userdata;
-  nsi->nsp = (mspool *)nsockp;
+  nsi->nsp = (struct npool *)nsockp;
 
   nsi->_flags = 0;
 
@@ -151,27 +150,27 @@ nsock_iod nsi_new2(nsock_pool nsockp, int sd, void *userdata) {
   if (nsi->id == 0)
     nsi->id = nsp->next_iod_serial++;
 
-  /* The nsp keeps track of active msiods so it can delete them if it is deleted */
+  /* The nsp keeps track of active iods so it can delete them if it is deleted */
   gh_list_append(&nsp->active_iods, &nsi->nodeq);
 
-  nsock_log_info(nsp, "nsi_new (IOD #%lu)", nsi->id);
+  nsock_log_info("nsock_iod_new (IOD #%lu)", nsi->id);
 
   return (nsock_iod)nsi;
 }
 
 /* Defined in nsock_core.c. */
-int socket_count_zero(msiod *iod, mspool *ms);
+int socket_count_zero(struct niod *iod, struct npool *ms);
 
-/* If msiod_new returned success, you must free the iod when you are done with
+/* If nsock_iod_new returned success, you must free the iod when you are done with
  * it to conserve memory (and in some cases, sockets).  After this call,
  * nsockiod may no longer be used -- you need to create a new one with
- * nsi_new().  pending_response tells what to do with any events that are
+ * nsock_iod_new().  pending_response tells what to do with any events that are
  * pending on this nsock_iod.  This can be NSOCK_PENDING_NOTIFY (send a KILL
  * notification to each event), NSOCK_PENDING_SILENT (do not send notification
  * to the killed events), or NSOCK_PENDING_ERROR (print an error message and
  * quit the program) */
-void nsi_delete(nsock_iod nsockiod, enum nsock_del_mode pending_response) {
-  msiod *nsi = (msiod *)nsockiod;
+void nsock_iod_delete(nsock_iod nsockiod, enum nsock_del_mode pending_response) {
+  struct niod *nsi = (struct niod *)nsockiod;
   gh_lnode_t *evlist_ar[3];
   gh_list_t *corresp_list[3];
   int i;
@@ -185,16 +184,16 @@ void nsi_delete(nsock_iod nsockiod, enum nsock_del_mode pending_response) {
     return;
   }
 
-  nsock_log_info(nsi->nsp, "nsi_delete (IOD #%lu)", nsi->id);
+  nsock_log_info("nsock_iod_delete (IOD #%lu)", nsi->id);
 
   if (nsi->events_pending > 0) {
-    /* shit -- they killed the msiod while an event was still pending on it.
-     * Maybe I should store the pending events in the msiod.  On the other hand,
+    /* shit -- they killed the struct niod while an event was still pending on it.
+     * Maybe I should store the pending events in the iod.  On the other hand,
      * this should be a pretty rare occurrence and so I'll save space and hassle
      * by just locating the events here by searching through the active events
      * list */
     if (pending_response == NSOCK_PENDING_ERROR)
-      fatal("nsi_delete called with argument NSOCK_PENDING_ERROR on a nsock_iod that has %d pending event(s) associated with it", nsi->events_pending);
+      fatal("nsock_iod_delete called with argument NSOCK_PENDING_ERROR on a nsock_iod that has %d pending event(s) associated with it", nsi->events_pending);
 
     assert(pending_response == NSOCK_PENDING_NOTIFY || pending_response == NSOCK_PENDING_SILENT);
 
@@ -208,16 +207,16 @@ void nsi_delete(nsock_iod nsockiod, enum nsock_del_mode pending_response) {
 
     for (i = 0; i < 3 && nsi->events_pending > 0; i++) {
       for (current = evlist_ar[i]; current != NULL; current = next) {
-        msevent *nse;
+        struct nevent *nse;
 
         next = gh_lnode_next(current);
-        nse = lnode_msevent(current);
+        nse = lnode_nevent(current);
 
         /* we're done with this list of events for the current IOD */
         if (nse->iod != nsi)
           break;
 
-        msevent_cancel(nsi->nsp, nse, corresp_list[i], current, pending_response == NSOCK_PENDING_NOTIFY);
+        nevent_delete(nsi->nsp, nse, corresp_list[i], current, pending_response == NSOCK_PENDING_NOTIFY);
       }
     }
   }
@@ -243,7 +242,7 @@ void nsi_delete(nsock_iod nsockiod, enum nsock_del_mode pending_response) {
 #endif
 
     if (SSL_shutdown(nsi->ssl) == -1) {
-      nsock_log_info(nsi->nsp, "nsi_delete: SSL shutdown failed (%s) on NSI %li",
+      nsock_log_info("nsock_iod_delete: SSL shutdown failed (%s) on NSI %li",
                      ERR_reason_error_string(SSL_get_error(nsi->ssl, -1)), nsi->id);
     }
 
@@ -293,33 +292,28 @@ void nsi_delete(nsock_iod nsockiod, enum nsock_del_mode pending_response) {
 
 /* Returns the ID of an nsock_iod . This ID is always unique amongst ids for a
  * given nspool (unless you blow through billions of them). */
-unsigned long nsi_id(nsock_iod nsockiod) {
+unsigned long nsock_iod_id(nsock_iod nsockiod) {
   assert(nsockiod);
-  return ((msiod *)nsockiod)->id;
+  return ((struct niod *)nsockiod)->id;
 }
 
 /* Returns the SSL object inside an nsock_iod, or NULL if unset. */
-nsock_ssl nsi_getssl(nsock_iod nsockiod) {
+nsock_ssl nsock_iod_get_ssl(nsock_iod iod) {
 #if HAVE_OPENSSL
-  return ((msiod *)nsockiod)->ssl;
+  return ((struct niod *)iod)->ssl;
 #else
   return NULL;
 #endif
 }
 
-/* Returns the SSL_SESSION of an nsock_iod, and increments it's usage count. */
-nsock_ssl_session nsi_get1_ssl_session(nsock_iod nsockiod) {
+/* Returns the SSL_SESSION of an nsock_iod.
+ * Increments its usage count if inc_ref is not zero. */
+nsock_ssl_session nsock_iod_get_ssl_session(nsock_iod iod, int inc_ref) {
 #if HAVE_OPENSSL
-  return SSL_get1_session(((msiod *)nsockiod)->ssl);
-#else
-  return NULL;
-#endif
-}
-
-/* Returns the SSL_SESSION without incrementing usage count. */
-nsock_ssl_session nsi_get0_ssl_session(nsock_iod nsockiod) {
-#if HAVE_OPENSSL
-  return SSL_get0_session(((msiod *)nsockiod)->ssl);
+  if (inc_ref)
+    return SSL_get1_session(((struct niod *)iod)->ssl);
+  else
+    return SSL_get0_session(((struct niod *)iod)->ssl);
 #else
   return NULL;
 #endif
@@ -328,7 +322,7 @@ nsock_ssl_session nsi_get0_ssl_session(nsock_iod nsockiod) {
 /* sets the ssl session of an nsock_iod, increments usage count. The session
  * should not have been set yet (as no freeing is done) */
 #if HAVE_OPENSSL
-void nsi_set_ssl_session(msiod *iod, SSL_SESSION *sessid) {
+void nsi_set_ssl_session(struct niod *iod, SSL_SESSION *sessid) {
   if (sessid) {
     iod->ssl_session = sessid;
     /* No reference counting for the copy stored briefly in nsiod */
@@ -336,30 +330,30 @@ void nsi_set_ssl_session(msiod *iod, SSL_SESSION *sessid) {
 }
 #endif
 
-/* Sometimes it is useful to store a pointer to information inside the msiod so
+/* Sometimes it is useful to store a pointer to information inside the struct niod so
  * you can retrieve it during a callback. */
-void nsi_setud(nsock_iod nsockiod, void *data) {
-  assert(nsockiod);
-  ((msiod *)nsockiod)->userdata = data;
+void nsock_iod_set_udata(nsock_iod iod, void *udata) {
+  assert(iod);
+  ((struct niod *)iod)->userdata = udata;
 }
 
 /* And the function above wouldn't make much sense if we didn't have a way to
  * retrieve that data... */
-void *nsi_getud(nsock_iod nsockiod) {
-  assert(nsockiod);
-  return ((msiod *)nsockiod)->userdata;
+void *nsock_iod_get_udata(nsock_iod iod) {
+  assert(iod);
+  return ((struct niod *)iod)->userdata;
 }
 
 /* Returns 1 if an NSI is communicating via SSL, 0 otherwise. */
-int nsi_checkssl(nsock_iod nsockiod) {
-  return (((msiod *)nsockiod)->ssl) ? 1 : 0;
+int nsock_iod_check_ssl(nsock_iod iod) {
+  return (((struct niod *)iod)->ssl) ? 1 : 0;
 }
 
 /* Returns the remote peer port (or -1 if unavailable).  Note the return value
  * is a whole int so that -1 can be distinguished from 65535.  Port is returned
  * in host byte order. */
-int nsi_peerport(nsock_iod nsockiod) {
-  msiod *nsi = (msiod *)nsockiod;
+int nsock_iod_get_peerport(nsock_iod iod) {
+  struct niod *nsi = (struct niod *)iod;
   int fam;
 
   if (nsi->peerlen <= 0)
@@ -378,33 +372,34 @@ int nsi_peerport(nsock_iod nsockiod) {
 }
 
 /* Sets the local address to bind to before connect() */
-int nsi_set_localaddr(nsock_iod nsi, struct sockaddr_storage *ss, size_t sslen) {
-  msiod *iod = (msiod *)nsi;
+int nsock_iod_set_localaddr(nsock_iod iod, struct sockaddr_storage *ss,
+                            size_t sslen) {
+  struct niod *nsi = (struct niod *)iod;
 
-  assert(iod);
+  assert(nsi);
 
-  if (sslen > sizeof(iod->local))
+  if (sslen > sizeof(nsi->local))
     return -1;
 
-  memcpy(&iod->local, ss, sslen);
-  iod->locallen = sslen;
+  memcpy(&nsi->local, ss, sslen);
+  nsi->locallen = sslen;
   return 0;
 }
 
 /* Sets IPv4 options to apply before connect(). It makes a copy of the options,
  * so you can free() yours if necessary. This copy is freed when the iod is
  * destroyed. */
-int nsi_set_ipoptions(nsock_iod nsi, void *opts, size_t optslen) {
-  msiod *iod = (msiod *)nsi;
+int nsock_iod_set_ipoptions(nsock_iod iod, void *opts, size_t optslen) {
+  struct niod *nsi = (struct niod *)iod;
 
-  assert(iod);
+  assert(nsi);
 
   if (optslen > 44)
     return -1;
 
-  iod->ipopts = safe_malloc(optslen);
-  memcpy(iod->ipopts, opts, optslen);
-  iod->ipoptslen = optslen;
+  nsi->ipopts = safe_malloc(optslen);
+  memcpy(nsi->ipopts, opts, optslen);
+  nsi->ipoptslen = optslen;
   return 0;
 }
 
@@ -415,37 +410,37 @@ int nsi_set_ipoptions(nsock_iod nsi, void *opts, size_t optslen) {
  * "reasonable" things with it, like setting socket receive buffers.  But don't
  * create havok by closing the descriptor!  If the descriptor you get back is
  * -1, the iod does not currently possess a valid descriptor */
-int nsi_getsd(nsock_iod nsockiod) {
-  msiod *iod = (msiod *)nsockiod;
+int nsock_iod_get_sd(nsock_iod iod) {
+  struct niod *nsi = (struct niod *)iod;
 
-  assert(nsockiod);
+  assert(nsi);
 
 #if HAVE_PCAP
-  if (iod->pcap)
-    return ((mspcap *)iod->pcap)->pcap_desc;
+  if (nsi->pcap)
+    return ((mspcap *)nsi->pcap)->pcap_desc;
   else
 #endif
-    return iod->sd;
+    return nsi->sd;
 }
 
-unsigned long nsi_get_read_count(nsock_iod nsockiod){
-  assert(nsockiod);
-  return ((msiod *)nsockiod)->read_count;
+unsigned long nsock_iod_get_read_count(nsock_iod iod){
+  assert(iod);
+  return ((struct niod *)iod)->read_count;
 }
 
-unsigned long nsi_get_write_count(nsock_iod nsockiod){
-  assert(nsockiod);
-  return ((msiod *)nsockiod)->write_count;
+unsigned long nsock_iod_get_write_count(nsock_iod iod){
+  assert(iod);
+  return ((struct niod *)iod)->write_count;
 }
 
-int nsi_set_hostname(nsock_iod nsi, const char *hostname) {
-  msiod *iod = (msiod *)nsi;
+int nsock_iod_set_hostname(nsock_iod iod, const char *hostname) {
+  struct niod *nsi = (struct niod *)iod;
 
-  if (iod->hostname != NULL)
-    free(iod->hostname);
+  if (nsi->hostname != NULL)
+    free(nsi->hostname);
 
-  iod->hostname = strdup(hostname);
-  if (iod->hostname == NULL)
+  nsi->hostname = strdup(hostname);
+  if (nsi->hostname == NULL)
     return -1;
 
   return 0;
