@@ -200,7 +200,7 @@ struct seq_info {
   u32 timestamps[NUM_SEQ_SAMPLES];
   int index;
   u16 ipids[NUM_SEQ_SAMPLES];
-  long lastboot; /* 0 means unknown */
+  time_t lastboot; /* 0 means unknown */
 };
 
 /* Different kinds of Ipids. */
