@@ -7,7 +7,7 @@ if __name__ == "__main__":
     import glob
     import os
     if not hasattr(unittest.defaultTestLoader, "discover"):
-        print("Python unittest discovery missing. Requires Python 2.7 or newer.")
+        print("Python unittest discovery missing. Requires Python 2.7 or newer.")  # noqa
         sys.exit(0)
 
     os.chdir("..")
