@@ -3,7 +3,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -94,8 +94,7 @@
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
@@ -116,7 +115,7 @@
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 # * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
 # * license file for more details (it's in a COPYING file included with     *
-# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -135,15 +134,16 @@ class TargetList(object):
             self.target_list_file = False
 
         #import pdb; pdb.set_trace()
-        if self.target_list_file and \
-            (access(self.target_list_file, R_OK and W_OK) or \
-             access(dirname(self.target_list_file), R_OK and W_OK)):
+        if (self.target_list_file and
+                (access(self.target_list_file, R_OK and W_OK) or
+                    access(dirname(self.target_list_file), R_OK and W_OK))):
             self.using_file = True
 
             # Recovering saved targets
             target_file = open(self.target_list_file, "r")
-            self.temp_list = [t for t in target_file.read().split(";") \
-                                    if t != "" and t != "\n"]
+            self.temp_list = [
+                    t for t in target_file.read().split(";")
+                    if t != "" and t != "\n"]
             target_file.close()
         else:
             self.using_file = False
