@@ -3,7 +3,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -94,8 +94,7 @@
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
@@ -116,7 +115,7 @@
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 # * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
 # * license file for more details (it's in a COPYING file included with     *
-# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -146,19 +145,19 @@ from zenmapGUI.ScriptInterface import *
 
 def get_option_check_auxiliary_widget(option, ops, check):
     if option in ("-sI", "-b", "--script", "--script-args", "--exclude", "-p",
-        "-D", "-S", "--source-port", "-e", "--ttl", "-iR", "--max-retries",
-        "--host-timeout", "--max-rtt-timeout", "--min-rtt-timeout",
-        "--initial-rtt-timeout", "--max-hostgroup", "--min-hostgroup",
-        "--max-parallelism", "--min-parallelism", "--max-scan-delay",
-        "--scan-delay", "-PA", "-PS", "-PU", "-PO", "-PY"):
+            "-D", "-S", "--source-port", "-e", "--ttl", "-iR", "--max-retries",
+            "--host-timeout", "--max-rtt-timeout", "--min-rtt-timeout",
+            "--initial-rtt-timeout", "--max-hostgroup", "--min-hostgroup",
+            "--max-parallelism", "--min-parallelism", "--max-scan-delay",
+            "--scan-delay", "-PA", "-PS", "-PU", "-PO", "-PY"):
         return OptionEntry(option, ops, check)
     elif option in ("-d", "-v"):
         return OptionLevel(option, ops, check)
     elif option in ("--excludefile", "-iL"):
         return OptionFile(option, ops, check)
     elif option in ("-A", "-O", "-sV", "-n", "-6", "-Pn", "-PE", "-PP", "-PM",
-        "-PB", "-sC", "--script-trace", "-F", "-f", "--packet-trace", "-r",
-        "--traceroute"):
+            "-PB", "-sC", "--script-trace", "-F", "-f", "--packet-trace", "-r",
+            "--traceroute"):
         return None
     elif option in ("",):
         return OptionExtras(option, ops, check)
@@ -497,9 +496,8 @@ class OptionBuilder(object):
         return dic
 
     def __parse_groups(self):
-        return [g_name.getAttribute(u'name') for g_name in \
-                  self.xml.getElementsByTagName(u'groups')[0].\
-                  getElementsByTagName(u'group')]
+        return [g_name.getAttribute(u'name') for g_name in
+                self.xml.getElementsByTagName(u'groups')[0].getElementsByTagName(u'group')]  # noqa
 
     def __parse_tabs(self):
         dic = {}
